%% load the spectra

    clear all
    close all

    fname_lower = 'datafiles/CC_V210_C_Auto_BaselineCorrection.txt';
    fname_upper = 'datafiles/CC_V210_S_Sap1_BaselineCorrection.txt';

    savefile_basename = "plots/v20240513_withBC/V210_comparison";   % DO NOT put a file extension on this - it will be added later

    raw_lower = LoadNMR_v2(fname_lower);
    raw_upper = LoadNMR_v2(fname_upper);

    PlotNMRs( [raw_lower raw_upper], 1, 0, 0 );

    max_lower = max( raw_lower.intensity(raw_lower.chemshift < 4));
    max_upper = max( raw_upper.intensity(raw_upper.chemshift < 4));

    set(gca,'YLim',[-0.1 1.1]*max(max_lower,max_upper))
    yline(0,'--k')
    legend('Lower','Upper')
    
%% shift/align the spectra

    refshift = 4.17;

    title('Click on the C peak for PDADMA on the lower phase (BLACK) trace:')
    click_lower = ginput(1);
    title('Click on the C peak for PDADMA on the upper phase (RED) trace:')
    click_upper = ginput(1);

    shifted_lower = raw_lower;
    shifted_lower.chemshift = shifted_lower.chemshift - click_lower(1) + refshift;
    shifted_lower = ShiftNMR( shifted_lower, refshift );

    shifted_upper = raw_upper;
    shifted_upper.chemshift = shifted_upper.chemshift - click_upper(1) + refshift;
    shifted_upper = ShiftNMR( shifted_upper, refshift );

    PlotNMRs( [shifted_lower shifted_upper], 1, 0, 0 );
    set(gca,'YLim',[-0.1 1.1]*max(max_lower,max_upper))
    yline(0,'--k')
    legend('Lower','Upper')
    title('Verify that spectra are shifted correctly before proceeding!')
    
%% baseline-correct the spectra

    baselineranges = [0 0.5;
                      5.5 6.1;
                      8.5 9.5];

    shifted_upper = BGcorrNMRv2( shifted_upper, baselineranges, 2 );
    shifted_lower = BGcorrNMRv2( shifted_lower, baselineranges, 2 );

%% calculate integrals

    %calculate integrals in the aromatic and aliphatic regions
    int_ranges = [6.35 7.3;     % a,b - aromatic
                  7.3 8.2;      % a,b - aromatic
                  4.00 4.33;    % c
                  3.35 3.81;    % c,d
                  2.54 3.15;    % e
                  0.85 2.54];   % f,g,h

    for i = 1:length(int_ranges)
        upper_I(i) = IntegrateNMR(shifted_upper, int_ranges(i,:));
        lower_I(i) = IntegrateNMR(shifted_lower, int_ranges(i,:));
    end
    
%% write integrals (and calculated PSS/PDADMA ratios) to a file

    x_PSS_all =@(I) ( (I(1)+I(2))*4 )/( (I(1)+I(2))*4 + sum(I(3:end)) - (I(1)+I(2))*3/4 );
    x_PSS_abc =@(I) ((I(1)+I(2))/4)/((I(1)+I(2))/4 + I(3)/2);

    fid = fopen(strcat(savefile_basename,'_integrals.txt'), 'w');
    
    fprintf(fid, "Integration ranges:\n");
    fprintf(fid, "Range %d: from %0.2f to %0.2f ppm\n", [1:length(int_ranges); int_ranges']);
    fprintf(fid, "\n");
    
    fprintf(fid, "Lower Phase\n");
    fprintf(fid, "Filename: %s\n", fname_lower);
    fprintf(fid, "Integrals: \n");
    fprintf(fid, "\tRange %d: \t%6.2f\n", [1:length(int_ranges); lower_I]);
    fprintf(fid, "Mole fraction PSS from ALL peaks: \t%0.3f\n", x_PSS_all(lower_I) )
    fprintf(fid, "Mole fraction PSS from a,b,c peaks: \t%0.3f\n", x_PSS_abc(lower_I) )
    fprintf(fid, "\n")
    
    fprintf(fid, "Upper Phase\n");
    fprintf(fid, "Filename: %s\n", fname_upper);
    fprintf(fid, "Integrals: \n");
    fprintf(fid, "\tRange %d: \t%6.2f\n", [1:length(int_ranges); upper_I]);
    fprintf(fid, "Mole fraction PSS from ALL peaks: \t%0.3f\n", x_PSS_all(upper_I))
    fprintf(fid, "Mole fraction PSS from a,b,c peaks: \t%0.3f\n", x_PSS_abc(upper_I) )
    fprintf(fid, "\n")
    
    fclose(fid);

%% normalize the NMRs to the total number of repeat units

    upper_I_arom = upper_I(1) + upper_I(2);
    upper_I_aliph = sum(upper_I(3:end));
    normalized_upper = shifted_upper;
    normalized_upper.intensity = normalized_upper.intensity/( 3.25*upper_I_arom + upper_I_aliph );
    
    lower_I_arom = lower_I(1) + lower_I(2);
    lower_I_aliph = sum(lower_I(3:end));
    normalized_lower = shifted_lower;
    normalized_lower.intensity = normalized_lower.intensity/( 3.25*lower_I_arom + lower_I_aliph );

    % figure out what the max value BELOW 4 ppm (so well below the water
    % peak
    lower_max = max(normalized_lower.intensity( normalized_lower.chemshift < 4 ));
    upper_max = max(normalized_upper.intensity( normalized_upper.chemshift < 4 ));
    the_max = max([lower_max upper_max]);

%% plot!  make two copies so that we can make one zoomed in on the y axis and the other not

    for fignum = [2,3]

        PlotNMRs( [normalized_lower normalized_upper], fignum, 0, 0 );
        legend('Lower','Upper')
        yline(0,'--k')

        % tweak the plot formatting to make it pretty
        if fignum == 2
            lims = [-0.1 1.1];
        else
            lims = [-0.015 0.165];
        end
        set(gca,'XLim',[0 9],'YLim',the_max*lims,'LineWidth',2,'FontSize',12)
        set(gcf,'units','inches','Position',[1 1 6.5 2.5])
        
        if(fignum==2)
            savefile = savefile_basename;
        else
            savefile = strcat(savefile_basename, "_zoom");
        end
        
        savefig(gcf,strcat(savefile,".fig"))
        saveas(gcf,strcat(savefile,".pdf"))
       
    end